/*
	This file is part of the smb library
    Copyright (C) 1999  Nicolas Brodu
    brodu@iie.cnam.fr

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
#ifndef __IO_DESCRIPTORS_H__
#define __IO_DESCRIPTORS_H__
#include "order.h"

// We need a structure to record information about the files we
// open. And it enables us to use our own file descriptors, instead
// of those sent by SMB servers, for which we can say nothing.
// in the futur it could lead to a use of real fd through pipes
// so that smb will be more transparent, and it could be used
// too implement a kind of virtual filesystem when browsing

// At present, a list is used, fd numbers are assigned
// from 1 when the list is created, and a new cell gets number
// "last cell of the list"->fd+1
// so that no two ones are the same
class FdCell
{
public:
	int fd;  // our own file descriptor
	int fid; // file id sent by server
	char *name; // file name
	char *workgroup;
	char *host;
	char *share;
	char *dir;
	char *user; // userName
 	uint32 st_mode;     /* protection */
	uint32 st_uid;      /* user ID of owner */
	uint32 st_gid;      /* group ID of owner */
	uint32 st_size;     /* total size, in bytes */
	uint32 st_atime;    /* time of last access */
	uint32 st_mtime;    /* time of last modification */
	uint32 st_ctime;    /* time of last change */
	int handle; // handle for operations on remote server
	int handleExist; // handle can be 0 ! so if (handle) doesn't work :-(
	uint32 pos; // current position in file for I/O
	uint8 *cache; // cache
	uint8 *cpos;  // cache current position/pointer
	int clen;    // cache length
	int cinvalid; // cache invalid boolean
	FdCell *next; // next cell in list
	FdCell(int _fd, int _fid, const char* _name, const char *_workgroup, const char* _host, const char* _share, const char* _dir, const char* _user, uint32 size=0);
	~FdCell();
	int copy(FdCell *fdc); // deep copy, including cache
};


void destroyFdList(FdCell *l);
int getNewFd(void* &fdInfo, int fid=-1, const char* name=0, const char* workgroup=0,
	 const char* host=0, const char* share=0, const char* dir=0, const char* user=0, uint32 size=0);
int closeFd(void* &fdInfo, int fd);
FdCell *getFdCellFromFd(FdCell* fdInfo, int fd);
//FdCell *getFdCellFromData(FdCell* fdInfo, const char* name=0, const char* workgroup=0,
//	const char* host=0, const char* share=0, const char* dir=0, const char* user=0);



#endif //__IO_DESCRIPTORS_H__
