/*
	This file is part of the smb library
    Copyright (C) 1999  Nicolas Brodu
    brodu@iie.cnam.fr

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
#ifndef __IO_TYPES_H__
#define __IO_TYPES_H__
#include "order.h"

// For external & internal use
// The list destroys itself if you delete the first cell
// those defines are also used in openService
#define SMB_DISK 0
#define SMB_PRINT_QUEUE 1
#define SMB_DEVICE 2
#define SMB_IPC 3
class SMBShareList
{
public:
	char *name;
	int type;	// one of the defines above
	char *comment;
	SMBShareList *next;
	SMBShareList(const char* n=0, int t=SMB_DISK, const char* c=0, SMBShareList *ne=0);
	~SMBShareList();
};

class SMBMasterList
{
public:
	char *name;
	SMBMasterList *next;
	SMBMasterList(const char* n=0, SMBMasterList *ne=0);
	~SMBMasterList(); // destroy recursively
};

class SMBMemberList
{
public:
	char *name; // member name
	char *comment; // comment on this member if available
	SMBMemberList *next;
	SMBMemberList(const char* n=0, const char* c=0, SMBMemberList *ne=0);
	~SMBMemberList(); // destroy recursively
};

class SMBWorkgroupList
{
public:
	char *name; // workgroup name
	SMBMasterList *possibleMasters; // workgroup master for this workgroup
	SMBMemberList *members; // members of this workgroup
	uint32 lastCheck;  // date of last check. enable timeouts
	SMBWorkgroupList *next;
	// WARNING : do not copy the full member & master list...
	SMBWorkgroupList(const char* n=0, SMBMasterList* ma=0, SMBMemberList *me=0, SMBWorkgroupList *ne=0);
	~SMBWorkgroupList(); // destroy recursively
};

class SMBdirent
{
public:
 	uint32 st_mode;     /* protection */
	uint32 st_uid;      /* user ID of owner */
	uint32 st_gid;      /* group ID of owner */
	uint32 st_size;     /* total size, in bytes */
	uint32 st_atime;    /* time of last access */
	uint32 st_mtime;    /* time of last modification */
	uint32 st_ctime;    /* time of last change */
 	char *d_name;
	SMBdirent();
	~SMBdirent();
};

#endif // __IO_TYPES_H__
